// -*- C++ -*-
/*
 * Simple gtkglextmm example using libglademm.
 *
 * written by Naofumi Yasufuku  <naofumi@users.sourceforge.net>
 * restructured and libglade support by Dirc Rose <rose@vis.uni-stuttgart.de>
 *
 */

#include "simpleGLwithGlade.h"
#include "simpleGLscene.h"

Simple::Simple(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
  : Gtk::Window(cobject),
    m_refGlade(refGlade),
    m_ButtonQuit(0)
{

  m_refGlade->get_widget("QuitButton", m_ButtonQuit);
  if (m_ButtonQuit)
  {
    m_ButtonQuit->signal_clicked().connect( SigC::slot(*this, &Simple::on_button_quit_clicked) );
  }

  //Get the Glade-instantiated drawingarea
  SimpleGLScene *m_SimpleGLScene = 0;
  m_refGlade->get_widget_derived("DrawArea", m_SimpleGLScene);
}

Simple::~Simple()
{}

void Simple::on_button_quit_clicked()
{
  Gtk::Main::quit();
}


///////////////////////////////////////////////////////////////////////////////
// Main.
///////////////////////////////////////////////////////////////////////////////

int main(int argc, char** argv)
{
  Gtk::Main kit(argc, argv);

  // Init gtkglextmm.
  Gtk::GL::init(argc, argv);

  // Query OpenGL extension version.
  int major, minor;
  Gdk::GL::query_version(major, minor);
  std::cout << "OpenGL extension version - "
            << major << "." << minor << std::endl;

  // Instantiate and run the application.
  // Load the Glade file and instiate its widgets:
  Glib::RefPtr<Gnome::Glade::Xml> refXml;
  try
  {
    refXml = Gnome::Glade::Xml::create("simpleGLwithGlade.glade");
  }
  catch(const Gnome::Glade::XmlError& ex)
  {
    std::cerr << ex.what() << std::endl;
    return 1;
  }

  Simple *simple = 0;
  refXml->get_widget_derived("window1", simple);
  if (simple)
  {
    kit.run(*simple);
  }

  return 0;
}
